package com.fs.qw.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.common.core.domain.R;
import com.fs.his.param.FsReceivePhoneRedPacketParam;
import com.fs.qw.domain.RedPacket;

/**
 * 授权手机号红包配置Service接口
 * 
 * @author fs
 * @date 2026-03-17
 */
public interface IRedPacketService extends IService<RedPacket>{
    /**
     * 查询授权手机号红包配置
     * 
     * @param id 授权手机号红包配置主键
     * @return 授权手机号红包配置
     */
    RedPacket selectRedPacketById(Long id);

    /**
     * 查询授权手机号红包配置列表
     * 
     * @param redPacket 授权手机号红包配置
     * @return 授权手机号红包配置集合
     */
    List<RedPacket> selectRedPacketList(RedPacket redPacket);

    /**
     * 新增授权手机号红包配置
     * 
     * @param redPacket 授权手机号红包配置
     * @return 结果
     */
    int insertRedPacket(RedPacket redPacket);

    /**
     * 修改授权手机号红包配置
     * 
     * @param redPacket 授权手机号红包配置
     * @return 结果
     */
    int updateRedPacket(RedPacket redPacket);

    /**
     * 批量删除授权手机号红包配置
     * 
     * @param ids 需要删除的授权手机号红包配置主键集合
     * @return 结果
     */
    int deleteRedPacketByIds(Long[] ids);

    /**
     * 删除授权手机号红包配置信息
     * 
     * @param id 授权手机号红包配置主键
     * @return 结果
     */
    int deleteRedPacketById(Long id);

    /**
     * 获取授权红包信息
     * @param recordId 记录id
     */
    R getPhoneRedPacketInfo(Long recordId);

    R receivePhoneRedPacket(FsReceivePhoneRedPacketParam param);
}
